pub struct AskResult {
pub query: String,
pub input_type: String,
pub decisions: Vec<DecisionHit>,
pub timeline: Vec<DecisionHit>,
pub related_commits: Vec<CommitHit>,
pub related_notes: Vec<NoteHit>,
pub conversations: Vec<ConversationHit>,
pub tasks: Vec<TaskHit>,
pub dependents: Vec<DependentHit>,
pub override_risk: Option<OverrideRisk>,
pub workspace_event_count: Option<u64>,
pub workspace_decision_count: Option<u64>,
}Fields
query: Stringinput_type: Stringdecisions: Vec<DecisionHit>timeline: Vec<DecisionHit>conversations: Vec<ConversationHit>tasks: Vec<TaskHit>Tasks whose title/receipt/reason match the query — the rail’s answer to “what shipped about X, verified how” (GH-404).
dependents: Vec<DependentHit>override_risk: Option<OverrideRisk>workspace_event_count: Option<u64>Count of total events in the workspace ledger, if known.
workspace_decision_count: Option<u64>Count of total decisions in the workspace ledger, if known.